This package contains a number of utility modules that are helpful
with machine learning tasks.  Most of the modules work together with
`scikit-learn <http://scikit-learn.org/>`_, others are more generally
useful.

View the `documentation here <http://packages.python.org/nolearn/>`_.
